This cube models cards that are like wiki pages.

`Card` entities have a title, an abstract and some textual content as text, rest
or html.

To create a new card, just create a link like '/card/YOUR_WIKI_ID' and follow it
in your browser. Such a link can be written using the native HTML editor
(fckeditor) or the dedicated restructured text "card" directive, as follows ::

  :card:`free_software/logilab:free software at Logilab`
